.. UPC-NLP documentation master file, created by
   sphinx-quickstart on Fri Dec 27 11:57:29 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

UPC-NLP documentation
=====================

This is the documentation for an educational python package supporting introductory classes to Natural Language Processing
and computational linguistics at Université Paris Cité.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   langmodel
   datasets
